@@ -329,7 +329,8 @@ n.islands <- max(W.islands$nc)
         det.Q.proposal <- 0.5 * sum(log((proposal.rho * Wstar.val + (1-proposal.rho))))              
         logprob.current <- det.Q.W - temp2.phi / tau2.phi
         logprob.proposal <- det.Q.proposal - temp3 / tau2.phi
-        prob <- exp(logprob.proposal - logprob.current)
+        hastings <- log(dtruncnorm(x=rho, a=0, b=1, mean=proposal.rho, sd=proposal.sd.rho)) - log(dtruncnorm(x=proposal.rho, a=0, b=1, mean=rho, sd=proposal.sd.rho)) 
+        prob <- exp(logprob.proposal - logprob.current + hastings)
         
         #### Accept or reject the proposal
             if(prob > runif(1))
@@ -355,7 +356,8 @@ n.islands <- max(W.islands$nc)
         det.Q.proposal <- 0.5 * sum(log((proposal.lambda * Dstar.val + (1-proposal.lambda))))              
         logprob.current <- det.Q.D - temp2.delta / tau2.delta
         logprob.proposal <- det.Q.proposal - temp3 / tau2.delta
-        prob <- exp(logprob.proposal - logprob.current)
+        hastings <- log(dtruncnorm(x=lambda, a=0, b=1, mean=proposal.lambda, sd=proposal.sd.lambda)) - log(dtruncnorm(x=proposal.lambda, a=0, b=1, mean=lambda, sd=proposal.sd.lambda)) 
+        prob <- exp(logprob.proposal - logprob.current + hastings)
         
         #### Accept or reject the proposal
             if(prob > runif(1))
