@@ -1,4 +1,4 @@
-poisson.CARanova <- function(formula, data=NULL, W, interaction=TRUE, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=TRUE, verbose=TRUE)
+poisson.CARanova <- function(formula, data=NULL, W, interaction=TRUE, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=FALSE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -299,12 +299,12 @@ n.islands <- max(W.islands$nc)
     ## Sample from beta
     ###################
     offset.temp <- offset + as.numeric(phi.mat) + as.numeric(delta.mat) + as.numeric(gamma.mat)   
-        if(p>2)
+        if(MALA)
         {
         temp <- poissonbetaupdateMALA(X.standardised, N.all, p, beta, offset.temp, Y.DA, prior.mean.beta, prior.var.beta, n.beta.block, proposal.sd.beta, list.block)
         }else
         {
-        temp <- poissonbetaupdateRW(X.standardised, N.all, p, beta, offset.temp, Y.DA, prior.mean.beta, prior.var.beta, proposal.sd.beta)
+        temp <- poissonbetaupdateRW(X.standardised, N.all, p, beta, offset.temp, Y.DA, prior.mean.beta, prior.var.beta, n.beta.block, proposal.sd.beta, list.block)
         }
     beta <- temp[[1]]
     accept[1] <- accept[1] + temp[[2]]
@@ -417,8 +417,9 @@ n.islands <- max(W.islands$nc)
         det.Q.proposal <- 0.5 * sum(log((proposal.rho * Wstar.val + (1-proposal.rho))))              
         logprob.current <- det.Q.W - temp2.phi / tau2.phi
         logprob.proposal <- det.Q.proposal - temp3 / tau2.phi
-        prob <- exp(logprob.proposal - logprob.current)
-
+        hastings <- log(dtruncnorm(x=rho, a=0, b=1, mean=proposal.rho, sd=proposal.sd.rho)) - log(dtruncnorm(x=proposal.rho, a=0, b=1, mean=rho, sd=proposal.sd.rho)) 
+        prob <- exp(logprob.proposal - logprob.current + hastings)
+        
         #### Accept or reject the proposal
             if(prob > runif(1))
             {
@@ -444,7 +445,8 @@ n.islands <- max(W.islands$nc)
         det.Q.proposal <- 0.5 * sum(log((proposal.lambda * Dstar.val + (1-proposal.lambda))))              
         logprob.current <- det.Q.D - temp2.delta / tau2.delta
         logprob.proposal <- det.Q.proposal - temp3 / tau2.delta
-        prob <- exp(logprob.proposal - logprob.current)
+        hastings <- log(dtruncnorm(x=lambda, a=0, b=1, mean=proposal.lambda, sd=proposal.sd.lambda)) - log(dtruncnorm(x=proposal.lambda, a=0, b=1, mean=lambda, sd=proposal.sd.lambda)) 
+        prob <- exp(logprob.proposal - logprob.current + hastings)
 
         #### Accept or reject the proposal
             if(prob > runif(1))
@@ -583,7 +585,7 @@ mean.phi <- apply(samples.phi, 2, mean)
 mean.delta <- apply(samples.delta, 2, mean)  
 mean.phi.mat <- matrix(rep(mean.phi, N), byrow=F, nrow=K)
 mean.delta.mat <- matrix(rep(mean.delta, K), byrow=T, nrow=K)
-mean.beta <- apply(samples.beta,2,median)
+mean.beta <- apply(samples.beta,2,mean)
 regression.mat <- matrix(X.standardised %*% mean.beta, nrow=K, ncol=N, byrow=FALSE)   
     if(interaction)
     {
